#!/usr/bin/env node

var program = require('commander');
var chalk = require('chalk');
var path = require('path');
var file = require('../lib/file');
var UglifyJS = require("uglify-js");

program
    .option('-w, --watch', 'monitor the changes of project, auto build')
    .option('-u, --uglify', 'uglify all files')
    .parse(process.argv);

function build() {
    var config = file.read('config.json');
    if(config) {
        config = JSON.parse(config);

        var html = config.html;
        var css = config.css;
        var js = config.js;
        var bncStatic = {
            html: {},
            css: {}
        };
        if(html && html.length > 0) {
            html.map(function (value) {
                bncStatic.html[value] = file.read(value);
            });
        }
        if(css && css.length > 0) {
            css.map(function (value) {
                bncStatic.css[value] = file.read(value);
            });
        }
        var allJS = js.map(function (value) {
            return file.read(value);
        });

        var content = '(function(){\n';
        content += 'var bncStatic = '+ JSON.stringify(bncStatic) + ';\n';
        if(program.uglify) {
            content += UglifyJS.minify(allJS.join(';')).code;
        } else {
            content += allJS.join(';');
        }
        content += '})()';

        var filename = path.join(process.cwd(), 'entry.js');
        console.log(chalk.green('release: ' + filename));
        file.write(filename, content + '\n');
    }
}


build();
var timer = null;

if(program.watch) {
    file.watch(function () {
        if(timer) {
            clearTimeout(timer);
        }
        timer = setTimeout(function () {
            build();
        }, 500);
    })
}